@@ -4,6 +4,7 @@ household. The household has a heat demand which allows the chp
 to run for at least 5000 hours in a year.
 
 """
+import logging
 from pysimmods.generator.chplpgsim import CHPLPG
 from pysimmods.model.generator import Generator
 from pysimmods.other.heatdemandsim.heatdemand import create_heatdemand
@@ -12,6 +13,8 @@ from .config import CHPLPGSystemConfig
 from .inputs import CHPLPGSystemInputs
 from .state import CHPLPGSystemState
 
+LOG = logging.getLogger(__name__)
+
 
 class CHPLPGSystem(Generator):
     """CHP system with CHP and household"""
@@ -44,17 +47,37 @@ class CHPLPGSystem(Generator):
     def step(self):
         """Perform a simulation step"""
 
-        # First step the household
-        self.heatdemand.inputs.step_size = self.inputs.step_size
-        self.heatdemand.inputs.day_avg_t_air_deg_celsius = (
-            self.inputs.day_avg_t_air_deg_celsius
-        )
-        self.heatdemand.step()
+        err = None
+        try:
+            # First step the household
+            self.heatdemand.inputs.step_size = self.inputs.step_size
+            self.heatdemand.inputs.day_avg_t_air_deg_celsius = (
+                self.inputs.day_avg_t_air_deg_celsius
+            )
+            self.heatdemand.step()
+        except TypeError as te:
+            err = te
 
         # Second step the chp
         p_set_kw = self._check_setpoint()
         self.chp.set_now_dt(self.inputs.now_dt)
-        self.chp.inputs.e_th_demand_set_kwh = self.heatdemand.state.e_th_kwh
+        if self.inputs.e_th_demand_set_kwh is not None:
+            self.chp.inputs.e_th_demand_set_kwh = (
+                self.inputs.e_th_demand_set_kwh * self.config.e_th_demand_sign
+            )
+        elif err is None:
+            self.chp.inputs.e_th_demand_set_kwh = (
+                self.heatdemand.state.e_th_kwh
+            )
+        else:
+            msg = (
+                "One input is missing for CHP. Must at least provide "
+                "one of 'day_avg_t_air_deg_celsius' or "
+                "'e_th_demand_kwh'!"
+            )
+            LOG.error(msg)
+            raise ValueError(msg)
+
         self.chp.set_step_size(self.inputs.step_size)
         self.chp.set_p_kw(p_set_kw * self.config.gsign)
         self.chp.step()
@@ -65,7 +88,10 @@ class CHPLPGSystem(Generator):
         self.state.p_th_kw = self.chp.state.p_th_kw
         self.state.storage_t_c = self.chp.state.storage_t_c
         self.state.lubricant_l = self.chp.state.lubricant_l
-        self.state.e_th_demand_kwh = self.heatdemand.state.e_th_kwh
+        if self.inputs.e_th_demand_set_kwh is not None:
+            self.state.e_th_demand_kwh = self.inputs.e_th_demand_set_kwh
+        else:
+            self.state.e_th_demand_kwh = self.heatdemand.state.e_th_kwh
 
         self.inputs.reset()
 
