@@ -30,4 +30,9 @@ class DummyGenerator(Generator):
         self.inputs = DummyGeneratorInputs()
 
     def step(self):
-        self.state.p_kw = self.inputs.p_set_kw
+        self.state.p_kw = abs(self.inputs.p_set_kw)
+        if self.state.p_kw != 0:
+            self.state.p_kw = min(
+                self.config.p_max_kw,
+                max(self.config.p_min_kw, self.state.p_kw),
+            )
