@@ -3,6 +3,7 @@ the model interfaces. Their purpose is mainly for testing.
 
 """
 
+from typing import Any, Dict
 from pysimmods.model.config import ModelConfig
 from pysimmods.model.inputs import ModelInputs
 from pysimmods.model.model import Model
@@ -10,11 +11,13 @@ from pysimmods.model.state import ModelState
 
 
 class DummyConfig(ModelConfig):
-    def __init__(self, params):
+    def __init__(self, params: Dict[str, Any]):
         super().__init__(params)
 
-        self.p_max_kw = params.get("p_max_kw", 500)
-        self.p_min_kw = params.get("p_min_kw", 250)
+        self.p_max_kw: float = params.get("p_max_kw", 500)
+        self.p_min_kw: float = params.get("p_min_kw", 250)
+        self.default_p_schedule = [375.0] * 24
+        self.default_q_schedule = [125.0] * 24
 
 
 class DummyState(ModelState):
