@@ -4,10 +4,9 @@ for the chp.
 
 """
 import math
-import os
 import random
 from copy import deepcopy
-from datetime import datetime, timedelta
+from datetime import timedelta
 
 from pysimmods.other.heatdemandsim import (
     HeatDemandConfig,
@@ -15,12 +14,11 @@ from pysimmods.other.heatdemandsim import (
     HeatDemandState,
     hprofiles,
 )
-from pysimmods.model.model import Model
 
 DEMAND_PROFILES = dict()
 
 
-class HeatDemand(Model):
+class HeatDemand:
     """A simple model for thermal power demand.
 
     :constant CHP_AVERAGE_RUNTIME:
@@ -111,6 +109,39 @@ class HeatDemand(Model):
         """Returns the current thermal power demand"""
         return self.state.e_th_kwh
 
+    def get_state(self) -> dict:
+        """Return the current state of the model.
+
+        Returns
+        -------
+        dict
+            The current state of the model in form of a dictionary
+            containing entries for all state variables. Returned dict
+            can be assigned to the *inits* argument when creating a new
+            model instance.
+
+        """
+
+        try:
+            return {
+                attr: getattr(self.state, attr)
+                for attr in self.state.__slots__
+            }
+        except AttributeError:
+            return deepcopy(self.state.__dict__)
+
+    def set_state(self, state: dict) -> None:
+        """Set the current state of the model.
+
+        Parameters
+        ----------
+        state : dict
+            A *dict* containing entries for all state variables.
+
+        """
+        for attr, value in state.items():
+            setattr(self.state, attr, value)
+
 
 def create_heatdemand(config, state):
     """Creates a household object"""
